@@ -27,7 +27,7 @@
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-cvs-plugin.glade"
+#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-cvs-plugin.ui"
 
 extern GType cvs_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_CVS         (cvs_plugin_get_type (NULL))
@@ -64,6 +64,9 @@ struct _CVSPlugin{
 	gchar *fm_current_filename;
 	gchar *project_root_dir;
 	gchar *current_editor_filename;
+
+	/* Settings */
+	GSettings* settings;
 };
 
 struct _CVSPluginClass{
