@@ -23,32 +23,16 @@
  * USA.
  */
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib.h>
+#include <gdk/gdk.h>
 
 #ifndef _DND_H_
 #define _DND_H_
 
-/*
- * Maximum number of mime types that the widget can handle droppings for.
- */
-#define DND_MAX_MIME_TYPES 20
-
-/*
- * dnd_drop_init () - Initialize a widget to accept "droppings".
- *	
- * - GtkWidget *widget
- * 	Widget which will respond to the drags a.k.a "droppings".
- * - void (* data_dropped) (gchar *file_name, gpointer data)
- *	A pointer to the user supplied function which will handle the
- *      "droppings" (file_name).
- * - gpointer data
- *      Any user supplied data. This will be passed on to the callback. 
- * - ... [char *mime_type]
- *	NULL terminated list of accepted mime types.
- */
 void dnd_drop_init (GtkWidget *widget,
-	 				void (* data_dropped) (const gchar *uri, gpointer data),
-					gpointer data, ...);
+	 				void (* data_dropped) (GFile *uri, gpointer data),
+					gpointer user_data);
 
 void dnd_drop_finalize (GtkWidget *widget, gpointer user_data);
 
