@@ -51,6 +51,11 @@
 #include "git-clear-stash-pane.h"
 #include "git-rebase-pane.h"
 #include "git-log-pane.h"
+#include "git-reset-pane.h"
+#include "git-revert-pane.h"
+#include "git-cherry-pick-pane.h"
+#include "git-patch-series-pane.h"
+#include "git-apply-mailbox-pane.h"
 
 AnjutaCommandBarEntry branch_entries[] =
 {
@@ -81,7 +86,7 @@ AnjutaCommandBarEntry branch_entries[] =
 	{
 		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
 		"Switch",
-		N_("Switch to this branch"),
+		N_("Switch to the selected branch"),
 		N_("Switch to the selected branch"),
 		GTK_STOCK_JUMP_TO,
 		G_CALLBACK (on_switch_branch_button_clicked)
@@ -353,6 +358,114 @@ AnjutaCommandBarEntry stash_entries[] =
 	}
 };
 
+static AnjutaCommandBarEntry log_entries[] = 
+{
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
+		"NULL",
+		N_("Revision tools"),
+		NULL,
+		NULL,
+		NULL
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"ShowCommitDiff",
+		N_("Show commit diff"),
+		N_("Show a diff of the selected revision"),
+		GTK_STOCK_ZOOM_100,
+		G_CALLBACK (on_commit_diff_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"CherryPick",
+		N_("Cherry pick"),
+		N_("Merge an individual commit from another branch"),
+		NULL,
+		G_CALLBACK (on_cherry_pick_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
+		"NULL",
+		N_("Reset/Revert"),
+		NULL,
+		NULL,
+		NULL
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"Reset",
+		N_("Reset tree"),
+		N_("Reset tree to a previous revision"),
+		GTK_STOCK_REFRESH,
+		G_CALLBACK (on_reset_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"Revert",
+		N_("Revert commit"),
+		N_("Revert a commit"),
+		GTK_STOCK_UNDO,
+		G_CALLBACK (on_revert_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
+		"NULL",
+		N_("Patch series"),
+		NULL,
+		NULL,
+		NULL
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"GeneratePatchSeries",
+		N_("Generate a patch series"),
+		N_("Generate a patch series"),
+		NULL,
+		G_CALLBACK (on_patch_series_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
+		"NULL",
+		N_("Mailbox files"),
+		NULL,
+		NULL,
+		NULL
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"ApplyMailboxFiles",
+		N_("Apply mailbox files"),
+		N_("Apply patches from mailbox files"),
+		NULL,
+		G_CALLBACK (on_apply_mailbox_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"ApplyMailboxContinue",
+		N_("Continue"),
+		N_("Continue applying patches with resolved conflicts"),
+		NULL,
+		G_CALLBACK (on_apply_mailbox_continue_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"ApplyMailboxSkip",
+		N_("Skip"),
+		N_("Skip the current patch in the series"),
+		NULL,
+		G_CALLBACK (on_apply_mailbox_skip_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"ApplyMailboxAbort",
+		N_("Abort"),
+		N_("Stop applying the patch series and return the tree to its previous state"),
+		NULL,
+		G_CALLBACK (on_apply_mailbox_abort_button_clicked)
+	}
+};
+
 static gpointer parent_class;
 
 static void
@@ -519,6 +632,22 @@ on_branch_list_command_data_arrived (AnjutaCommand *command, Git *plugin)
 	}
 }
 
+static void
+git_register_stock_icons (AnjutaPlugin *plugin)
+{
+        static gboolean registered = FALSE;
+
+        if (registered)
+                return;
+        registered = TRUE;
+
+        /* Register stock icons */
+		BEGIN_REGISTER_ICON (plugin)
+		REGISTER_ICON_FULL ("anjuta-git-plugin", "git-plugin");
+		REGISTER_ICON_FULL ("anjuta-git-tasks", "git-tasks");
+		END_REGISTER_ICON
+}
+
 static gboolean
 git_activate_plugin (AnjutaPlugin *plugin)
 {
@@ -530,6 +659,8 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	
 	git_plugin = ANJUTA_PLUGIN_GIT (plugin);
 
+	git_register_stock_icons (plugin);
+	
 	/* Command bar and dock */
 	git_plugin->command_bar = anjuta_command_bar_new ();
 	git_plugin->dock = anjuta_dock_new ();
@@ -562,11 +693,11 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	                             ANJUTA_COMMAND_BAR (git_plugin->command_bar));
 
 	anjuta_shell_add_widget (plugin->shell, git_plugin->command_bar_window, 
-	                         "GitCommandBar", _("Git Tasks"), NULL,
+	                         "GitCommandBar", _("Git Tasks"), "git-tasks",
 	                         ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
 
 	anjuta_shell_add_widget (plugin->shell, git_plugin->dock_window, "GitDock", 
-	                         _("Git"), NULL, ANJUTA_SHELL_PLACEMENT_CENTER,
+	                         _("Git"), "git-plugin", ANJUTA_SHELL_PLACEMENT_CENTER,
 	                         NULL);
 
 	/* Create the branch list commands. There are two commands because some 
@@ -631,7 +762,8 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	git_plugin->log_pane = git_log_pane_new (git_plugin);
 	anjuta_dock_add_pane (ANJUTA_DOCK (git_plugin->dock), "Log",
 	                      _("Log"), NULL, git_plugin->log_pane,
-	                      GDL_DOCK_CENTER, NULL, 0, NULL);
+	                      GDL_DOCK_CENTER, log_entries,
+	                      G_N_ELEMENTS (log_entries), git_plugin);
 	
 	git_plugin->branches_pane = git_branches_pane_new (git_plugin);
 	anjuta_dock_add_pane (ANJUTA_DOCK (git_plugin->dock), "Branches", 
