@@ -17,6 +17,8 @@ typedef struct _StarterPluginClass StarterPluginClass;
 struct _StarterPlugin{
 	AnjutaPlugin parent;
 	GtkWidget *starter;
+	gint editor_watch_id;
+	gint project_watch_id;
 };
 
 struct _StarterPluginClass{
